if {![file exist "tkblog.cfg" ]} {
    puts "ERROR! Couldn't find tkblog.cfg"
    exit
} else {
    source ./tkblog.cfg
}

namespace eval blagv {
          variable start        [clock format [clock seconds] -format "%c"]
          variable bloghome     [pwd]
          variable version      "Blarc v2.25"
          variable logname      "$bloghome/blog.log"
          variable newsession   1
          variable logid        "--"
          variable blogdata     "archive/blog.dat"
          variable server       $server
          variable user         $user
          variable passwd       $passwd
          variable arcdir       $arcdir
          variable archtml      $archtml
          variable basedate     $basedate
          variable interval     $interval
          variable advarc       $advarc
          variable advarchtml   "$bloghome/$advarc$advarchtml"
          variable larcdir      "$bloghome/archives/"
          variable header       "$bloghome/header.template"
          variable footer       "$bloghome/footer.template"
}

package require ftp

proc logmsg {msg} {

      set  timestamp [clock format [clock seconds] -format "%d %b %H:%M:%S"]
      set  logfile [open $blagv::logname a]

      if {$blagv::newsession==1} {
         puts $logfile "\n  $timestamp  $blagv::logid $msg"
         set blagv::newsession 0
      }  else {
         puts $logfile "  $timestamp  $blagv::logid $msg"
      }
      close $logfile
}

logmsg "$blagv::version -- $blagv::start"

if {![file exist "archives"]} {
      file mkdir "archives"
      logmsg "Creating archives directory"
}

proc getarchash {} {
     global archive

     set blogdat      [open $blagv::blogdata]

     while {[gets $blogdat line]!=-1} {
           if {[regexp {<!-- blogid*} $line]} {
              set keep $line
              set bid [split $line]
              set bid [lindex $bid 2]
              set blog [append blog "$keep\n"]

              while {[gets $blogdat line]!=-1} {
                    if {![regexp {<!--/blog-->} $line]} {
                       set blog [append  blog "$line\n"]
                    } else {
                       set blog [append blog "$line\n"]
                       set archive($bid) $blog
                       set blog ""
                       break
                    }
              }
           }
     }
     close $blogdat
}

proc advarc {} {
     global archive

     set startid      [clock scan now -base [clock scan $blagv::basedate]]
     set startarc     [clock format $startid -format "%b %d %Y"]
     set endid        [clock scan $blagv::interval -base [clock scan $blagv::basedate]]
     set endarc       [clock format $endid -format "%b %d %Y"]

     set sortedarc [lsort [array names archive]]
     set totalblogs [llength $sortedarc]

     for {set x 0}  {$x<$totalblogs} {incr x } {
             set blogid [lindex $sortedarc $x] 

             if {$startid <= $blogid && $blogid < $endid} {
                set arcname  "$blagv::larcdir$startarc--$endarc.html"
                if {![catch {open $arcname a} barchive]} {
                   puts $barchive $archive($blogid)
                   close $barchive
                } else {
                   puts $barchive $archive($blogid)
                   close $barchive
                }
             } else {
                catch [close $barchive]
                set startid  [clock scan $blagv::interval -base [clock scan $startarc]]
                set startarc [clock format $startid -format "%b %d %Y"]
                set endid    [clock scan $blagv::interval -base [clock scan $endarc]]
                set endarc   [clock format $endid   -format "%b %d %Y"]
                incr x -1
             } 
     }
}

proc cleanarcdir {} {

     cd $blagv::larcdir
     logmsg "deleting old archives"

     foreach i [glob -nocomplain *] {
             if {[regexp {\.html$} $i] || [regexp {\.htm$} $i]} {
                file delete $i
             }
     }
}

proc applyhf {} {

     cd $blagv::larcdir
     logmsg "creating new archives"

     foreach i [glob -nocomplain *] {
             if {[regexp {\.html$} $i] && [file size $i]!=0} {
                set old [open $i]
                set i [file rootname $i]
                set new [open "$i.htm" w]
                set header [open $blagv::header]
                set footer [open $blagv::footer]

                while {[gets $header line]!=-1} {
                      puts $new $line
                }
                puts $new "<h3><u><center>$i</center></u><p>"
                while {[gets $old line]!=-1} {
                      puts $new $line
                }
                while {[gets $footer line]!=-1} {
                      puts $new $line
                }
                close $old
                close $new
                close $header
                close $footer
             }
     }
}

proc arcindex {} {

     cd $blagv::larcdir

     set archives [open $blagv::advarchtml w]
     set header [open $blagv::header]
     logmsg "Creating new: $blagv::advarchtml"
     while {[gets $header line]!=-1} {
           puts $archives $line
     }
     close $header

     foreach i [glob -nocomplain *] {
             if {[regexp {\.htm$} $i] && [file size $i]!=0} {
                set link [file rootname $i]
                puts $archives "<center><a href=\"$i\">$link</a></center><br>"
             }
     }
     set footer [open $blagv::footer]
     while {[gets $footer line]!=-1} {
           puts $archives $line
     }
     close $archives
}

proc sendarcs {} {

     logmsg "Getting ftp connection"
     if {[set conn [ftp::Open $blagv::server $blagv::user $blagv::passwd -progress Progress -blocksize 1024 -mode active]] == -1} {
          logmsg "Can't connect to $blggv::server" 
          return
     }
     logmsg "Sending archives to web page..."

     cd $blagv::larcdir

     foreach i [glob -nocomplain *] {
             if {[regexp {\.htm$} $i]} {
                if {[catch [ftp::Put $conn $i  $blagv::arcdir$i]]} {
                     logmsg "Sent $i"
                } else {
                     logmsg "Can't send to $blagv::server $i NOT sent"
                     return
                }
             }
     }
}

getarchash
cleanarcdir
advarc
applyhf
arcindex
sendarcs
logmsg "Blarc exit..."
